"""
Pubsub package initialization.

:copyright: Copyright since 2006 by Oliver Schoenborn, all rights reserved.
:license: BSD, see LICENSE_BSD_Simple.txt for details.
"""

_PREVIOUS_RELEASE_DATE = "2013-09-15"
_PREVIOUS_RELEASE_VER = "3.2.1b"

__version__ = "3.3.0"

__all__ = [
    'pub',
    'utils',
    'setupkwargs',
    'setuparg1',
    '__version__'
    ]

import wx
import warnings
warnings.warn('wx.lib.pubsub has been deprecated, please migrate your '
              'code to use pypubsub, available on PyPI.',
              wx.wxPyDeprecationWarning)
